# Items1


## Properties

Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**dtype** | [**DType**](DType.md) |  | 
**object** | [**Dict[str, BaseColumnParameterSchemaAllowedColumnTypesInner]**](BaseColumnParameterSchemaAllowedColumnTypesInner.md) |  | 
**items** | [**Items1**](Items1.md) |  | 

## Example

```python
from arthur_client.api_bindings.models.items1 import Items1

# TODO update the JSON string below
json = "{}"
# create an instance of Items1 from a JSON string
items1_instance = Items1.from_json(json)
# print the JSON string representation of the object
print(Items1.to_json())

# convert the object into a dict
items1_dict = items1_instance.to_dict()
# create an instance of Items1 from a dict
items1_from_dict = Items1.from_dict(items1_dict)
```
[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


